
from bigquery_sql_parser.line import Line


def test_identation():
    string = '    column_name'

    line = Line(string)
    assert len(line.identation) == 4


def test_from_clause():
    string = '  from table'

    line = Line(string)
    assert line.is_from_clause


def test_select_clause():
    string = 'select * from table'

    line = Line(string)
    assert line.is_select_clause
    assert not line.is_only_select_clause


def test_add_comma():
    string = 'select name'

    line = Line(string)
    line.add_comma()
    assert line.content == 'select name,'



import re


class Line:
    def __init__(self, content):
        self.content = content

    @property
    def identation(self):
        matches = re.match(r'^\s+', self.content)
        if matches:
            return matches.group(0)
        return ''

    @property
    def is_from_clause(self):
        return 'from' in self.content.lower()

    @property
    def is_select_clause(self):
        return 'select' in self.content.lower()

    @property
    def is_only_select_clause(self):
        matches = re.match(r'(?i)^\s*select\s*\n', self.content)
        return True if matches else False

    def add_comma(self):
        self.content = self.content+','
